
import com.vladium.evil.EvilThrow;

// ----------------------------------------------------------------------------
/**
 * This {@link IFoo} implementation demonstrates that it is easy to break
 * the 'throws' contract of any method. To accomplish that EvilFoo relies
 * on <code>com.vladium.evil.EvilThrow</code> class, the source of which cannot be
 * be shown in compilable Java. The article explains how that class was created
 * and explains alternate ways of breaking 'throws' contracts in Java.
 * 
 * @author (C) <a href="mailto:vroubtsov@illinoisalumni.org">Vlad Roubtsov</a>, 2003
 */
public class EvilFoo implements IFoo, Runnable
{
    // public: ................................................................
    
    /**
     * @param throwthis any exception you would like to see thrown from
     * {@link #bar()} and {@link #run()}. 
     */
    public EvilFoo (final Throwable throwthis)
    {
        m_throwthis = throwthis;
    }

    /**
     * Implements {@link IFoo#bar()} and violates the 'throws' contract
     * of that interface.
     * 
     * @see IFoo#bar()
     */    
    public void bar ()
    {
        EvilThrow.throwThrowable (m_throwthis);
    }
    
    // Runnable:
    
    public void run ()
    {
        // this implementation causes a deadlock when used with 
        //SwingUtilities.invokeAndWait():
        
        bar ();
    }
    
    // protected: .............................................................

    // package: ...............................................................
    
    // private: ...............................................................

    private final Throwable m_throwthis;

} // end of class
// ----------------------------------------------------------------------------
